@@ -1,77 +1,14 @@
 package Net::Squid::Auth::Plugin::SimpleLDAP;
 
+# ABSTRACT: A simple LDAP-based credentials validation plugin for Net::Squid::Auth::Engine
+
 use warnings;
 use strict;
 use Carp;
 use Net::LDAP;
 use Scalar::Util qw/reftype/;
 
-=head1 NAME
-
-Net::Squid::Auth::Plugin::SimpleLDAP - A simple LDAP-based credentials validation plugin for Net::Squid::Auth::Engine
-
-=cut
-
-use version; our $VERSION = qv('0.1.82');
-
-=head1 SYNOPSIS
-
-If you're a system administrator trying to use Net::Squid::Auth::Engine to
-validate your user's credentials using a LDAP server as a credentials
-repository, do as described here:
-
-On C<$Config{InstallScript}/squid-auth-engine>'s configuration file:
-
-  plugin = SimpleLDAP
-  <SimpleLDAP>
-    # LDAP server
-    server = myldap.server.somewhere       # mandatory
-
-    # connection options
-    <NetLDAP>                              # optional section with
-      port = N                             #   Net::LDAP's
-      scheme = 'ldap' | 'ldaps' | 'ldapi'  #     constructor
-      ...                                  #     options
-    </NetLDAP>
-
-    # bind options
-    binddn = cn=joedoe                     # mandatory
-    bindpw = secretpassword                # mandatory
-
-    # search options
-    basedn = ou=mydept,o=mycompany.com     # mandatory
-    objclass = inetOrgPerson               # opt, default "person"
-    userattr = uid                         # opt, default "cn"
-    passattr = password                    # opt, default "userPassword"
-  </SimpleLDAP>
-
-Unless configured otherwise, this module will assume the users in your LDAP 
-directory belong to the object class C<person>, as defined in section 3.12 of 
-RFC 4519, and the B<user> and B<password> information will be looked for in the 
-C<cn> and C<userPassword> attributes, respectively. Although you can choose
-to use any other pair of attributes, the C<userattr> can be set to C<DN>,
-while the C<passattr> can not.
-
-On your Squid HTTP Cache configuration:
-
-    auth_param basic /usr/bin/squid-auth-engine /etc/squid-auth-engine.conf
-
-And you're ready to use this module.
-
-If you're a developer, you might be interested in reading through the source
-code of this module, in order to learn about it's internals and how it works.
-It may give you ideas about how to implement other plugin modules for
-L<Net::Squid::Auth::Engine>. 
-
-=head1 FUNCTIONS
-
-=head2 new( $config_hash )
-
-Constructor. Expects a hash reference with all the configuration under the
-section I<< <SimpleLDAP> >> in the C<$Config{InstallScript}/squid-auth-engine> 
-as parameter. Returns a plugin instance.
-
-=cut
+our $VERSION = '0.1.82_01';    # VERSION
 
 sub new {
     my ( $class, $config ) = @_;
@@ -94,15 +31,6 @@ sub new {
     return bless { _cfg => $config }, $class;
 }
 
-=head2 initialize()
-
-Initialization method called upon instantiation. This provides an opportunity 
-for the plugin initialize itself, stablish database connections and ensure it 
-have all the necessary resources to verify the credentials presented. It 
-receives no parameters and expect no return values.
-
-=cut
-
 sub initialize {
     my $self = shift;
 
@@ -120,14 +48,6 @@ sub initialize {
     return;
 }
 
-=head2 _search()
-
-Searches the LDAP server. It expects one parameter with a search string for
-the username. The search string must conform with the format used in LDAP
-queries, as defined in section 3 of RFC 4515.
-
-=cut
-
 sub _search {
     my ( $self, $search ) = @_;
 
@@ -171,14 +91,6 @@ sub _search {
     return $result;
 }
 
-=head2 is_valid( $username, $password )
-
-This is the credential validation interface. It expects a username and password
-as parameters and returns a boolean indicating if the credentials are valid
-(i.e., are listed in the configuration file) or not.
-
-=cut
-
 sub is_valid {
     my ( $self, $username, $password ) = @_;
     my $result = $self->_search("$username");
@@ -187,30 +99,105 @@ sub is_valid {
     return $result->{$username} eq $password;
 }
 
-=head2 config( $key )
-
-Accessor for a configuration setting given by key.
-
-=cut
-
 sub config {
     my ( $self, $key ) = @_;
 
     return $self->{_cfg}->{$key};
 }
 
-=head1 AUTHOR
+1;    # End of Net::Squid::Auth::Plugin::SimpleLDAP
 
-Alexei Znamensky, C<< <russoz at cpan.org> >>
+__END__
 
-=head1 BUGS
+=pod
 
-Please report any bugs or feature requests to 
-C<bug-net-squid-auth-plugin-simpleldap at rt.cpan.org>, or through 
-the web interface at 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-Squid-Auth-Plugin-SimpleLDAP>.  
-I will be notified, and then you'll automatically be notified of progress on 
-your bug as I make changes.
+=head1 NAME
+
+Net::Squid::Auth::Plugin::SimpleLDAP - A simple LDAP-based credentials validation plugin for Net::Squid::Auth::Engine
+
+=head1 VERSION
+
+version 0.1.82_01
+
+=head1 SYNOPSIS
+
+If you're a system administrator trying to use Net::Squid::Auth::Engine to
+validate your user's credentials using a LDAP server as a credentials
+repository, do as described here:
+
+On C<$Config{InstallScript}/squid-auth-engine>'s configuration file:
+
+  plugin = SimpleLDAP
+  <SimpleLDAP>
+    # LDAP server
+    server = myldap.server.somewhere       # mandatory
+
+    # connection options
+    <NetLDAP>                              # optional section with
+      port = N                             #   Net::LDAP's
+      scheme = 'ldap' | 'ldaps' | 'ldapi'  #     constructor
+      ...                                  #     options
+    </NetLDAP>
+
+    # bind options
+    binddn = cn=joedoe                     # mandatory
+    bindpw = secretpassword                # mandatory
+
+    # search options
+    basedn = ou=mydept,o=mycompany.com     # mandatory
+    objclass = inetOrgPerson               # opt, default "person"
+    userattr = uid                         # opt, default "cn"
+    passattr = password                    # opt, default "userPassword"
+  </SimpleLDAP>
+
+Unless configured otherwise, this module will assume the users in your LDAP
+directory belong to the object class C<person>, as defined in section 3.12 of
+RFC 4519, and the B<user> and B<password> information will be looked for in the
+C<cn> and C<userPassword> attributes, respectively. Although you can choose
+to use any other pair of attributes, the C<userattr> can be set to C<DN>,
+while the C<passattr> can not.
+
+On your Squid HTTP Cache configuration:
+
+    auth_param basic /usr/bin/squid-auth-engine /etc/squid-auth-engine.conf
+
+And you're ready to use this module.
+
+If you're a developer, you might be interested in reading through the source
+code of this module, in order to learn about it's internals and how it works.
+It may give you ideas about how to implement other plugin modules for
+L<Net::Squid::Auth::Engine>.
+
+=head1 METHODS
+
+=head2 new( $config_hash )
+
+Constructor. Expects a hash reference with all the configuration under the
+section I<< <SimpleLDAP> >> in the C<$Config{InstallScript}/squid-auth-engine>
+as parameter. Returns a plugin instance.
+
+=head2 initialize()
+
+Initialization method called upon instantiation. This provides an opportunity
+for the plugin initialize itself, stablish database connections and ensure it
+have all the necessary resources to verify the credentials presented. It
+receives no parameters and expect no return values.
+
+=head2 _search()
+
+Searches the LDAP server. It expects one parameter with a search string for
+the username. The search string must conform with the format used in LDAP
+queries, as defined in section 3 of RFC 4515.
+
+=head2 is_valid( $username, $password )
+
+This is the credential validation interface. It expects a username and password
+as parameters and returns a boolean indicating if the credentials are valid
+(i.e., are listed in the configuration file) or not.
+
+=head2 config( $key )
+
+Accessor for a configuration setting given by key.
 
 =head1 SUPPORT
 
@@ -270,15 +257,15 @@ To what I'd reply:
 
 "Only a master of Perl, Fields"
 
+=head1 AUTHOR
 
-=head1 COPYRIGHT & LICENSE
+Alexei Znamensky <russoz@cpan.org>
 
-Copyright 2008,2010 Alexei Znamensky, all rights reserved.
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2011 by Alexei Znamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-42;    # End of Net::Squid::Auth::Plugin::SimpleLDAP
-
